==> react-component-scroll-to-bottom-button-0.121.0.tgz: package/cjs/index.js <==
"use strict";

var _typeof = require("@babel/runtime-corejs2/helpers/typeof");
var _WeakMap = require("@babel/runtime-corejs2/core-js/weak-map");
var _Object$defineProperty = require("@babel/runtime-corejs2/core-js/object/define-property");
var _Object$getOwnPropertyDescriptor = require("@babel/runtime-corejs2/core-js/object/get-own-property-descriptor");
var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _classnames = _interopRequireDefault(require("classnames"));
var _reactComponentButton = _interopRequireDefault(require("@webex/react-component-button"));
var _reactComponentIcon = _interopRequireWildcard(require("@webex/react-component-icon"));
function _getRequireWildcardCache(nodeInterop) { if (typeof _WeakMap !== "function") return null; var cacheBabelInterop = new _WeakMap(); var cacheNodeInterop = new _WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = _Object$defineProperty && _Object$getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? _Object$getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { _Object$defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var styles = {
  "container": "container--2FPN1",
  "icon": "icon--XPVkt",
  "hidden": "hidden--2OJ-S",
  "withText": "withText--3YAoT",
  "label": "label--3ICjH"
}; // @related-file ./styles.css
var propTypes = {
  label: _propTypes.default.string,
  onClick: _propTypes.default.func.isRequired
};
var defaultProps = {
  label: ''
};
function ScrollToBottomButton(props) {
  var onClick = props.onClick,
    label = props.label;
  var containerStyle, labelSpan;
  if (label) {
    labelSpan = /*#__PURE__*/_react.default.createElement("span", {
      className: (0, _classnames.default)('webex-scroll-to-bottom-label', styles.label)
    }, label);
    containerStyle = styles.withText;
  }
  return /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _classnames.default)('webex-scroll-to-bottom-container', styles.container, containerStyle)
  }, /*#__PURE__*/_react.default.createElement(_reactComponentButton.default, {
    onClick: onClick
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _classnames.default)('webex-scroll-to-bottom-icon', styles.icon)
  }, /*#__PURE__*/_react.default.createElement(_reactComponentIcon.default, {
    type: _reactComponentIcon.ICONS.ICON_TYPE_RIGHT_ARROW
  })), labelSpan));
}
ScrollToBottomButton.propTypes = propTypes;
ScrollToBottomButton.defaultProps = defaultProps;
var _default = ScrollToBottomButton;
exports.default = _default;

==> react-component-scroll-to-bottom-button-0.126.0.tgz: package/cjs/index.js <==
"use strict";

var _typeof = require("@babel/runtime-corejs2/helpers/typeof");
var _WeakMap = require("@babel/runtime-corejs2/core-js/weak-map");
var _Object$defineProperty = require("@babel/runtime-corejs2/core-js/object/define-property");
var _Object$getOwnPropertyDescriptor = require("@babel/runtime-corejs2/core-js/object/get-own-property-descriptor");
var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _classnames = _interopRequireDefault(require("classnames"));
var _reactComponentButton = _interopRequireDefault(require("@webex/react-component-button"));
var _reactComponentIcon = _interopRequireWildcard(require("@webex/react-component-icon"));
function _getRequireWildcardCache(e) { if ("function" != typeof _WeakMap) return null; var r = new _WeakMap(), t = new _WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != _typeof(e) && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = _Object$defineProperty && _Object$getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? _Object$getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? _Object$defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
var styles = {
  "container": "container--2FPN1",
  "icon": "icon--XPVkt",
  "hidden": "hidden--2OJ-S",
  "withText": "withText--3YAoT",
  "label": "label--3ICjH"
}; // @related-file ./styles.css
var propTypes = {
  label: _propTypes.default.string,
  onClick: _propTypes.default.func.isRequired
};
var defaultProps = {
  label: ''
};
function ScrollToBottomButton(props) {
  var onClick = props.onClick,
    label = props.label;
  var containerStyle, labelSpan;
  if (label) {
    labelSpan = /*#__PURE__*/_react.default.createElement("span", {
      className: (0, _classnames.default)('webex-scroll-to-bottom-label', styles.label)
    }, label);
    containerStyle = styles.withText;
  }
  return /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _classnames.default)('webex-scroll-to-bottom-container', styles.container, containerStyle)
  }, /*#__PURE__*/_react.default.createElement(_reactComponentButton.default, {
    onClick: onClick
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _classnames.default)('webex-scroll-to-bottom-icon', styles.icon)
  }, /*#__PURE__*/_react.default.createElement(_reactComponentIcon.default, {
    type: _reactComponentIcon.ICONS.ICON_TYPE_RIGHT_ARROW
  })), labelSpan));
}
ScrollToBottomButton.propTypes = propTypes;
ScrollToBottomButton.defaultProps = defaultProps;
var _default = exports.default = ScrollToBottomButton;
